@@ -12,10 +12,11 @@
 #
 # The Initial Developer of the Original Code is CWI.
 # Portions created by CWI are Copyright (C) 1997-July 2008 CWI.
-# Copyright August 2008-2013 MonetDB B.V.
+# Copyright August 2008-2014 MonetDB B.V.
 # All Rights Reserved.
 
 import logging
+import platform
 
 from monetdb.sql import cursors
 from monetdb import exceptions
@@ -43,8 +44,6 @@ class Connection(object):
         autocommit  -- enable/disable auto commit (default: False)
 
         """
-        if not unix_socket:
-            unix_socket = "/tmp/.s.monetdb.%i" % port
 
         # The DB API spec is not specific about this
         if host:
@@ -52,6 +51,9 @@ class Connection(object):
         if user:
             username = user
 
+        if platform.system() == "Windows" and not hostname:
+            hostname = "localhost"
+
         self.mapi = mapi.Connection()
         self.mapi.connect(hostname=hostname, port=int(port), username=username,
                           password=password, database=database, language="sql",
